#ifndef _AUDIT_STATUS_UTILS_H_
#define _AUDIT_STATUS_UTILS_H_

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <sys/stat.h>
#include <limits.h>
#include <errno.h>

#ifdef __cplusplus
extern "C" {
#endif


  /**
 * @brief 获取系统是否已开启审计功能
 * @功能说明:获取系统是否已开启审计功能
 * @return int 内核及上层均未开启返回0；内核开启上层未开启返回1；
 *   内核未开启上层开启返回2；内核及上层均已开启返回3；获取异常返回-1
 */
int get_audit_status();


 /**
 * @brief 设置系统内核的审计功能，打开或关闭系统内核的审计功能
 * @功能说明:设置系统内核的审计功能，打开或关闭系统内核的审计功能
 * @param status 0 关闭,1开启 
 * @return int 返回0表示成功，返回非零表示失败
 */
int set_audit_status(int _switch);

 /**
 * @brief 设置grub配置文件
 * @功能说明:设置grub配置文件中audit对应的状态
 * @param status 0 关闭,1开启 
 * @return int 返回0表示成功，返回非零表示失败
 */
int set_audit_status_conf(int _switch);

#ifdef __cplusplus
}
#endif


#endif
